@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef CONTACTSTESTUTILS_H_
-#define CONTACTSTESTUTILS_H_
+#pragma once
 
 #include "types.h"
 #include "contact.h"
@@ -13,4 +12,3 @@
 KGAPI2::ContactPtr contactFromFile(const QString &path);
 KGAPI2::ContactsGroupPtr contactsGroupFromFile(const QString &path);
 
-#endif
