@@ -9,7 +9,7 @@
 #include "eventmovejob.h"
 #include "account.h"
 #include "calendarservice.h"
-#include "../debug.h"
+#include "debug.h"
 #include "event.h"
 #include "utils.h"
 #include "private/queuehelper_p.h"
