@@ -9,7 +9,7 @@
 #include "accountinfofetchjob.h"
 #include "account.h"
 #include "accountinfo.h"
-#include "../debug.h"
+#include "debug.h"
 #include "utils.h"
 
 #include <QNetworkRequest>
