@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef LIBKGAPI2_DRIVESERVICE_H
-#define LIBKGAPI2_DRIVESERVICE_H
+#pragma once
 
 #include "types.h"
 #include "kgapidrive_export.h"
@@ -117,4 +116,3 @@ namespace DriveService
 
 } // namespace KGAPI2
 
-#endif // KGAPI2_DRIVESERVICE_H
