@@ -10,7 +10,7 @@
 #include "taskdeletejob.h"
 #include "tasksservice.h"
 #include "account.h"
-#include "../debug.h"
+#include "debug.h"
 #include "task.h"
 #include "utils.h"
 #include "private/queuehelper_p.h"
